@@ -166,7 +166,7 @@ void KJobTest::testProgressTracking()
     totalChanged_spy.clear();
     percentChanged_spy.clear();
 
-    /**
+    /*!
      * Try again with Files as the progress unit
      */
     testJob->setProgressUnit(KJob::Files);
@@ -338,11 +338,12 @@ void KJobTest::testEmitAtMostOnce()
     }
 
     QVERIFY(!job->isFinished());
-    loop.processEvents(QEventLoop::AllEvents, 2000);
-    QCOMPARE(destroyed_spy.size(), autoDelete);
-    if (!autoDelete) {
-        QVERIFY(job->isFinished());
+    if (autoDelete) {
+        QTRY_COMPARE_WITH_TIMEOUT(destroyed_spy.size(), 1, 5000);
+    } else {
+        QTRY_VERIFY_WITH_TIMEOUT(job->isFinished(), 5000);
     }
+    QCOMPARE(destroyed_spy.size(), autoDelete);
 
     QVERIFY(!actions.empty());
     // The first action alone should determine the job's error and result.
@@ -409,27 +410,27 @@ void KJobTest::testElapseTimeSuspendResume()
     QSignalSpy suspended_spy(m_innerJob, &KJob::suspended);
     QSignalSpy resume_spy(m_innerJob, &KJob::resumed);
 
-    QTimer::singleShot(5, m_innerJob, [this]() {
+    QTimer::singleShot(500, m_innerJob, [this]() {
         m_innerJob->suspend();
-        QCOMPARE_GE(m_innerJob->elapsedTime(), 5);
-        QCOMPARE_LE(m_innerJob->elapsedTime(), 8);
+        QCOMPARE_GE(m_innerJob->elapsedTime(), 400);
+        QCOMPARE_LE(m_innerJob->elapsedTime(), 600);
     });
-    QTimer::singleShot(10, m_innerJob, &KJob::resume);
+    QTimer::singleShot(1000, m_innerJob, &KJob::resume);
 
-    QTimer::singleShot(15, m_innerJob, [this]() {
+    QTimer::singleShot(1500, m_innerJob, [this]() {
         m_innerJob->suspend();
-        QCOMPARE_GE(m_innerJob->elapsedTime(), 10);
-        QCOMPARE_LE(m_innerJob->elapsedTime(), 14);
+        QCOMPARE_GE(m_innerJob->elapsedTime(), 900);
+        QCOMPARE_LE(m_innerJob->elapsedTime(), 1100);
     });
-    QTimer::singleShot(20, m_innerJob, [this]() {
+    QTimer::singleShot(2000, m_innerJob, [this]() {
         m_innerJob->resume();
         m_innerJob->makeItFinish();
     });
 
     QVERIFY(m_innerJob->exec());
 
-    QCOMPARE_GE(m_innerJob->elapsedTime(), 10);
-    QCOMPARE_LE(m_innerJob->elapsedTime(), 14);
+    QCOMPARE_GE(m_innerJob->elapsedTime(), 900);
+    QCOMPARE_LE(m_innerJob->elapsedTime(), 1100);
 
     QCOMPARE(suspended_spy.count(), 2);
     QCOMPARE(resume_spy.count(), 2);
